@@ -49,6 +49,8 @@ public:
         SdrGamutWideness,
         ColorProfileSource,
         InteractiveMoveRole, // This output is currently repositioned interactively
+        BrightnessRole,
+        ColorPowerPreference,
     };
 
     explicit OutputModel(ConfigHandler *configHandler);
@@ -155,5 +157,5 @@ private:
 
     QList<Output> m_outputs;
 
-    ConfigHandler *m_config;
+    ConfigHandler *const m_config;
 };
